# {{ title }}

{{ description }}

## Features

{% block features %}
- Modern Python packaging with PEP 621 compliance
- Type hints and runtime type checking
- Comprehensive test suite and documentation
- CI/CD ready configuration
{% endblock %}

## Installation

```bash
pip install {{ name }}
```

## Usage

{% block usage %}
```python
import {{ import_name }}
```
{% endblock %}

## Development

This project uses [Hatch](https://hatch.pypa.io/) for development workflow management.

### Setup Development Environment

```bash
# Install hatch if you haven't already
pip install hatch

# Create and activate development environment
hatch shell

# Run tests
hatch run test

# Run tests with coverage
hatch run test-cov

# Run linting
hatch run lint

# Format code
hatch run format
```

## License

{{ license }} License 